from django.urls import path

from blogorama.api import views

urlpatterns = [
    # path("posts/", views.PostlListAPIView.as_view(), name="blogorama-post-list"),
    # path(
    #     "post/<slug:the_slug>/",
    # ),
]
