from rest_framework import generics

from blogorama.models import Post

# from blogorama.api.serializers import PostSerializer


# class PostlListAPIView(generics.ListAPIView):
# queryset = Post.objects.active()
#     serializer_class = SampleModelSerializer
